# Changelog

## [v0.1.0](https://github.com/XaviArnaus/pxavi-activitypub/releases/tag/v0.1.0) - 2025-06-16

### Added

- New repository abstracting ActivityPub classes, moving them from the `pyxavi` v0.8.0.
- Make the classes to be import-able from the package name
